@@ -39,6 +39,12 @@ file:///usr/share/doc/git-buildpackage/manual-html/gbp.import.html#GBP.IMPORT.CO
 on howto create it otherwise use --upstream-branch to specify it.
 """
 
+no_debian_branch_msg = """
+Repository does not have branch '%s' for packaging sources. If there is none see
+file:///usr/share/doc/git-buildpackage/manual-html/gbp.import.html#GBP.IMPORT.CONVERT
+on howto create it otherwise use --debian-branch to specify it.
+"""
+
 
 def expand_path(option, opt, value):
     value = os.path.expandvars(value)
@@ -102,6 +108,7 @@ class GbpOptionParser(OptionParser):
     @type def_config_files: dict (type, path)
     """
     defaults = {'abbrev': 7,
+                'aliases': 'True',
                 'allow-unauthenticated': 'False',
                 'arch': '',
                 'author-date-is-committer-date': 'False',
@@ -194,6 +201,9 @@ class GbpOptionParser(OptionParser):
                 'urgency': 'medium',
                 }
     help = {
+        'aliases':
+            "Whether to expand gbp specific aliases like `salsa:`,"
+            "default is '%(aliases)s'",
         'debian-branch':
             "Branch the Debian package is being developed on, "
             "default is '%(debian-branch)s'",
@@ -581,7 +591,7 @@ class GbpOptionParser(OptionParser):
         self.prefix = prefix
         self.config = {}
         self.valid_options = []
-        self.config_parser = configparser.SafeConfigParser()
+        self.config_parser = configparser.ConfigParser()
         self._warned_old_gbp_conf = False
 
         try:
